pub fn install_vst3_plugin_lib(cx: &mut Cx) -> Result<()>Expand description
Installs the Vst3PluginLib into cx, registering its adapter cards once.
Idempotent: a second call with the same cx is a no-op.
pub fn install_vst3_plugin_lib(cx: &mut Cx) -> Result<()>Installs the Vst3PluginLib into cx, registering its adapter cards once.
Idempotent: a second call with the same cx is a no-op.